@@ -1,5 +1,4 @@
 use nxui::demo::demodialog::DemoDialog;
-use nxui::util::*;
 use nxui::demo::demowindow::DemoWindow;
 use nxui::window::dialog::create_dialog;
 
@@ -8,7 +7,5 @@ fn main() {
     let dialog = DemoDialog::new();
     create_dialog(Box::new(dialog));
     let win = DemoWindow::new();
-    println!("{}",get_run_dir());
-    println!("OS: {}",get_os());
     nxui::nxui::create_new_app(Box::new(win));
 }
